export function parseArgsArray(argv) {
    const foundIndex = argv.findIndex((x) => x.startsWith('-'));
    const optionalBegin = foundIndex !== -1 ? foundIndex : argv.length;
    const positional = [...argv.slice(0, optionalBegin)];
    const optionalBuffer = [...argv.slice(optionalBegin)].reverse();
    const optional = {};
    let argName = undefined;
    let argValues = [];
    while (optionalBuffer.length > 0) {
        const item = optionalBuffer.pop();
        if (item.match(/^-[a-zA-Z0-9]{2,}$/)) {
            const items = item.slice(1).split('').reverse();
            optionalBuffer.push(...items.map((x) => `-${x}`));
            continue;
        }
        if (item.startsWith('-')) {
            if (argName !== undefined) {
                optional[argName] = argValues;
            }
            argName = item;
            argValues = [];
        }
        else {
            argValues.push(item);
        }
    }
    if (argName !== undefined) {
        optional[argName] = argValues;
    }
    return [positional, optional];
}
/**
 * Formats the argument name with alias.
 *
 * @param argConfig - The argument configuration.
 *
 * @returns The formatted argument name.
 *
 * @category Utils
 */
export function formatArgNameWithAlias(argConfig) {
    return `${argConfig.name}${argConfig.alias ? ` (${argConfig.alias})` : ''}`;
}
//# sourceMappingURL=utils.js.map